use std::{fs::File, io::{self, Read}, path::PathBuf};

use zip::ZipArchive;

pub fn extract_specific_folder<R: Read + io::Seek>(
    zip_archive: &mut ZipArchive<R>,
    source_folder: &str,
    destination_folder: &str,
) -> io::Result<()> {
    for i in 0..zip_archive.len() {
        let mut file = zip_archive.by_index(i)?;
        let file_name = file.name();

        // Check if the file is in the desired folder
        if file_name.starts_with(source_folder) {
            // Remove the source folder prefix
            let relative_path = file_name.strip_prefix(source_folder).unwrap_or(file_name);

            // Create the destination path
            let mut dest_path = PathBuf::from(destination_folder);
            dest_path.push(relative_path);

            if file.is_dir() {
                // Create the directory
                std::fs::create_dir_all(&dest_path)?;
            } else {
                // Create the destination directory if it doesn't exist
                if let Some(parent) = dest_path.parent() {
                    std::fs::create_dir_all(parent)?;
                }

                // Write the file to the destination
                let mut outfile = File::create(&dest_path)?;
                io::copy(&mut file, &mut outfile)?;
            }
        }
    }
    Ok(())
}
